# Embedding Gallery

This section contains the existing [`Embeddings`][distilabel.embeddings] subclasses implemented in `distilabel`.

::: distilabel.embeddings
    options:
        filters:
        - "!^Embeddings$"